@@ -1,10 +1,27 @@
+'''
+Module for locating and accessing [[https://takeout.google.com][Google Takeout]] data
+'''
+
+from dataclasses import dataclass
+from ...core.common import Paths
+
+from my.config import google as user_config
+@dataclass
+class google(user_config):
+    takeout_path: Paths # path/paths/glob for the takeout zips
+###
+
+# TODO rename 'google' to 'takeout'? not sure
+
+from ...core.cfg import make_config
+config = make_config(google)
+
 from pathlib import Path
 from typing import Optional, Iterable
 
 from ...common import get_files
 from ...kython.kompress import kopen, kexists
 
-from my.config import google as config
 
 def get_takeouts(*, path: Optional[str]=None) -> Iterable[Path]:
     """
