@@ -1,26 +1,40 @@
 """
 Twitter data (uses [[https://help.twitter.com/en/managing-your-account/how-to-download-your-twitter-archive][official twitter archive export]])
 """
+
+
+# before this config was named 'twitter', doesn't make too much sense for archive
+# try to import it defensively..
+try:
+    from my.config import twitter_archive as user_config
+except ImportError as e:
+    try:
+        from my.config import twitter as user_config
+    except ImportError:
+        raise e # raise the original exception.. must be somethingelse
+    else:
+        import warnings
+        warnings.warn('my.config.twitter is deprecated! Please rename it to my.config.twitter_archive in your config')
+
+
 from dataclasses import dataclass
 from ..core.common import Paths
 
-from my.config import twitter as user_config
-
+# TODO perhaps rename to twitter_archive? dunno
 @dataclass
-class twitter(user_config):
+class twitter_archive(user_config):
     export_path: Paths # path[s]/glob to the twitter archive takeout
 
 
 ###
 
 from ..core.cfg import make_config
-config = make_config(twitter)
+config = make_config(twitter_archive)
 
 
 from datetime import datetime
-from typing import Union, List, Dict, Set, Optional, Iterator, Any, NamedTuple
+from typing import Union, List, Dict, Set, Optional, Iterable, Any, NamedTuple, Sequence
 from pathlib import Path
-from functools import lru_cache
 import json
 import zipfile
 
@@ -34,8 +48,8 @@ from ..kython import kompress
 logger = LazyLogger(__name__)
 
 
-def _get_export() -> Path:
-    return max(get_files(config.export_path))
+def inputs() -> Sequence[Path]:
+    return get_files(config.export_path)[-1:]
 
 
 Tid = str
@@ -114,9 +128,10 @@ class Like(NamedTuple):
         return self.id_str
 
 
+from functools import lru_cache
 class ZipExport:
-    def __init__(self) -> None:
-        self.epath = _get_export()
+    def __init__(self, archive_path: Path) -> None:
+        self.epath = archive_path
 
         self.old_format = False # changed somewhere around 2020.03
         if not kompress.kexists(self.epath, 'Your archive.html'):
@@ -148,62 +163,24 @@ class ZipExport:
         [acc] = self.raw('account')
         return acc['username']
 
-    def tweets(self) -> Iterator[Tweet]:
+    def tweets(self) -> Iterable[Tweet]:
         for r in self.raw('tweet'):
             yield Tweet(r, screen_name=self.screen_name())
 
 
-    def likes(self) -> Iterator[Like]:
+    def likes(self) -> Iterable[Like]:
         # TODO ugh. would be nice to unify Tweet/Like interface
         # however, akeout only got tweetId, full text and url
         for r in self.raw('like'):
             yield Like(r, screen_name=self.screen_name())
 
 
-def tweets() -> List[Tweet]:
-    return list(sorted(ZipExport().tweets(), key=lambda t: t.dt))
+# todo not sure about list and sorting? although can't hurt considering json is not iterative?
+def tweets() -> Iterable[Tweet]:
+    for inp in inputs():
+        yield from sorted(ZipExport(inp).tweets(), key=lambda t: t.dt)
 
 
-def likes() -> List[Like]:
-    return list(ZipExport().likes())
-
-
-def test_tweet():
-    raw = """
- {
-  "retweeted" : false,
-  "entities" : {
-    "hashtags" : [ ],
-    "symbols" : [ ],
-    "user_mentions" : [ ],
-    "urls" : [ {
-      "url" : "https://t.co/vUg4W6nxwU",
-      "expanded_url" : "https://intelligence.org/2013/12/13/aaronson/",
-      "display_url" : "intelligence.org/2013/12/13/aar…",
-      "indices" : [ "120", "143" ]
-    }
-    ]
-  },
-  "display_text_range" : [ "0", "90" ],
-  "favorite_count" : "0",
-  "in_reply_to_status_id_str" : "24123424",
-  "id_str" : "2328934829084",
-  "in_reply_to_user_id" : "23423424",
-  "truncated" : false,
-  "retweet_count" : "0",
-  "id" : "23492349032940",
-  "in_reply_to_status_id" : "23482984932084",
-  "created_at" : "Thu Aug 30 07:12:48 +0000 2012",
-  "favorited" : false,
-  "full_text" : "this is a test tweet",
-  "lang" : "ru",
-  "in_reply_to_screen_name" : "whatever",
-  "in_reply_to_user_id_str" : "3748274"
-}
-    """
-    t = Tweet(json.loads(raw), screen_name='whatever')
-    assert t.permalink is not None
-    assert t.dt == datetime(year=2012, month=8, day=30, hour=7, minute=12, second=48, tzinfo=pytz.utc)
-    assert t.text == 'this is a test tweet'
-    assert t.tid  == '2328934829084'
-    assert t.entities is not None
+def likes() -> Iterable[Like]:
+    for inp in inputs():
+        yield from ZipExport(inp).likes()
